@@ -2,7 +2,7 @@ from decimal import Decimal
 from django.db.models import QuerySet, Sum
 
 
-def sum_queryset(qs: QuerySet, key: str= 'amount', default=Decimal(0)) -> Decimal:
+def sum_queryset(qs: QuerySet, key: str = 'amount', default: Decimal = Decimal(0)) -> Decimal:
     """
     Returns aggregate sum of queryset 'amount' field.
     :param qs: QuerySet
