@@ -1,6 +1,5 @@
 from jacc.models import AccountEntry, Account, Invoice, EntryType
-from django.utils.translation import ugettext as _
-from rest_framework import serializers
+from django.utils.translation import gettext as _
 from rest_framework.exceptions import ValidationError
 from rest_framework.serializers import ModelSerializer
 
